from enum import Enum


class FileStorage(Enum):
    """Available general file storage options."""

    CSV = "csv"
    PARQUET = "parquet"
    JSON = "json"
    GENERIC = "generic"


class DbStorage(Enum):
    """
    Available general DB storage options
    """

    JDBC = "JDBC"
    DELTA = "DELTA"
    CASSANDRA = "CASSANDRA"
    DYNAMODB = "DYNAMODB"
    HUDI = "HUDI"



"""
Enums module
"""
from .storage import DbStorage, FileStorage
from .spark_encodings import SparkEncoding
from .spark_savemodes import SaveMode


__all__ = ["DbStorage", "FileStorage", "SparkEncoding", "SaveMode"]
